==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/ar/users.php <==
<?php
regGS("Reset search form", "");
regGS("That user name already exists, please choose a different login name.", "");
regGS("User may delete article attachments", "");
regGS("User may change article attachments", "");
regGS("User may add article attachments", "");
regGS("Staff management", "");
regGS("Subscriber management", "");
regGS("Account Name", "");
regGS("Full Name", "الإسم الكامل");
regGS("Delete user $1", " $1 إلغاء المستخدم");
regGS("User list is empty.", "");
regGS("You do not have the right to create user accounts.", "لا يحق لك وضع اشتراكات للمستخدم");
regGS("Title", "الوظيفة");
regGS("Gender", "الجنس");
regGS("Mr.", "سيد");
regGS("Mrs.", "سيدة");
regGS("Ms.", "آنسة");
regGS("Dr.", "دكتور");
regGS("Male", "ذكر");
regGS("Female", "أنثى");
regGS("under 18", "دون الـ 18 سنة");
regGS("Age", "العمر");
regGS("Confirm password", "تأكيد كلمة السر");
regGS("E-Mail", "البريد الالكتروني");
regGS("City", "المدينة");
regGS("Street Address", "عنوان الشارع");
regGS("Postal Code", "الرمز البريدي");
regGS("State", "الولاية");
regGS("Phone", "الهاتف");
regGS("Fax", "الفاكس");
regGS("Contact Person", "الشخص المرجع");
regGS("Second Phone", "رقم هاتف ثان");
regGS("Employer", "رب العمل");
regGS("Employer Type", "نوع رب العمل");
regGS("Corporate", "شركة");
regGS("Non-Governmental Organisation", "منظمة غير حكومية");
regGS("Government Agency", "وكالة حكومية");
regGS("Academic", "أكاديمي");
regGS("Media", "إعلام");
regGS("Position", "مركز الوظيفة");
regGS("Show more user details", "");
regGS("Hide user details", "");
regGS("You must select a $1", "  $1عليك الاختيار ");
regGS("The password must be at least 6 characters long and both passwords should match.", "يجب أن تتألف كلمة السر من 6 أحرف على الأقل. كما يجب أن تكون كلمتا السر متشابهتين");
regGS("The user account could not be created.", "لا يمكن وضع اشتراك للمستخدم");
regGS("User account $1 was created successfully.", "");
regGS("Click here to change password", "");
regGS("Old Password", "");
regGS("You do not have the right to change user account permissions.", "لا يحق لك تغيير الاذن لاشتراك المستخدم");
regGS("Permissions for $1 changed", " $1 تغيير السماح ل ");
regGS("You do not have the right to change user account information.", "لا يحق لك تغيير معلومات اشتراك المستخدم");
regGS("Click here to customize user permissions", "");
regGS("Click here to use existing user type permissions (discard customization)", "");
regGS("Click here to leave password unchanged", "");
regGS("User account information changed for $1", "معلومات اشتراك المستخدم ل  $1");
regGS("The password you typed is incorrect.", "كلمة السر التي طبعتها غير صحيحة");
regGS("You do not have the right to delete user accounts.", "لا يحق لك إلغاء اشتراكات المستخدم");
regGS("Are you sure you want to delete the user account $1 ?", " هل أنت متأكد من أنك تريد إلغاء اشتراك المستخدم  $1 ؟");
regGS("User account $1 was deleted successfully.", "");
regGS("User IP access list management", "إدارة قائمة دخول المستخدم إلى بروتوكول الإنترنت");
regGS("No records.", "لا بيانات");
regGS("Start IP", "ابدأ بروتوكول الإنترنت");
regGS("Number of addresses", "عدد العناوين");
regGS("The IP Group $1 has been created.", "وضع مجموعة بروتوكول الإنترنت  $1");
regGS("There was an error creating the IP address group.", "");
regGS("Are you sure you want to delete the IP Group $1?", " هل أنت متأكد من أنك تريد إلغاء مجموعة بروتوكول الإنترنت  $1؟");
regGS("The IP address group $1 has been deleted.", "تم الغاء مجموعة عنوان بروتوكول الإنترنت  $1");
regGS("User '$1' information was changed successfully.", "");
regGS("IP address", "");
regGS("fill in from left to right at least one input box", "");
regGS("User Type", "");
regGS("You must input a valid EMail address.", "");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "");
regGS("Delete subscriptions to $1", "");
regGS("Change user account information", "غيّر معلومات اشتراك المستخدم");
regGS("The IP address group $1:$2 conflicts with another existing group.", "");
regGS("Creation Date", "");
regGS("User management", "إدارة المستخدم");
regGS("Set", "مجموعة");
regGS("Update", "تحديث");
regGS("Rights", "حقوق");
regGS("IP Access", "الدخول إلى بروتوكول الإنترنت");
regGS("User Name", "إسم المستخدم");
regGS("Staff", "موظف");
regGS("Adding new user account", "إضافة اشتراك لمستخدم جديد");
regGS("You must select an user type.", "يجب إختيار نوع المستخدم");
regGS("The user account $1 has been created.", "  $1 تم وضع اشتراك للمستخدم");
regGS("Please check if an account with the same user name does not already exist.", "الرجاء التأكد من أن اشتراكاّ باسم هذا المستخدم غير موجود مسبقاً");
regGS("Change password", "تغيير كلمة سرّ المستخدم");
regGS("You do not have the right to change user passwords.", "لا يحق تغيير كلمة سرّ المستخدم");
regGS("Changing user password", "تغيير كلمة سرّ المستخدم");
regGS("The password could not be changed.", "لا يمكن تغيير كلمة السرّ");
regGS("The password has been changed.", "تم تغيير كلمة السر");
regGS("User may manage templates", "يمكن للمستخدم إدارة النماذج");
regGS("User may add/change country entries", "يمكن للمستخدم إضافة بيانات البلدان أم تغييرها");
regGS("Edit user account permissions", "السماح لاشتراك المستخدم");
regGS("This user account does not have permissions information.", "ليس لدى اشتراك المستخدم المعلومات الاذن ");
regGS("Updating user account permissions", "تحديث الاذن لاشتراك المستخدم");
regGS("User account permissions have been successfuly updated.", "لقد تم تحديث الاذن لاشتراك المستخدم ");
regGS("User account permissions could not be updated.", "لا يمكن تغيير الاذن لاشتراك المستخدم");
regGS("Changing user account information", "تغيير معلومات اشتراك المستخدم");
regGS("User account information has been changed.", "تم تغيير معلومات اشتراك المستخدم");
regGS("User account information could not be changed.", "لا يمكن تغيير معلومات اشتراك المستخدم");
regGS("Old password", "كلمة السر القديمة");
regGS("New password", "كلمة السر الجديدة");
regGS("Confirm new password", "تأكيد كلمة السر الجديدة");
regGS("Changing your password", "تغيير كلمة السر الخاصة بك");
regGS("User $1 changed his password", "بدّل المستخدم 1$ كلمة السر الخاصة به");
regGS("Delete user account", "الغاء اشتراك المستخدم");
regGS("Deleting user account", "الغاء اشتراك المستخدم");
regGS("The user account $1 could not be deleted.", "لا يمكن إلغاء اشتراك المستخدم  $1");
regGS("No such user.", "هذا المستخدم غير موجود");
regGS("Delete IP Group $1", "الغاء مجموعة بروتوكول الإنترنت  $1");
regGS("IP Access List", "قائمة الدخول إلى بروتوكول الإنترنت");
regGS("Adding new IP Group", "إضافة مجموعة جديدة من بروتوكول الإنترنت");
regGS("The IP Group could not be created.", "لا يمكن وضع مجموعة بروتوكول الإنترنت ");
regGS("Please check if an account with the same IP Group does not already exist.", " الرجاء التأكد من عدم وجود اشتراك يتضمن مجموعة بروتوكول الإنترنت نفسها");
regGS("Delete IP Group", " إلغ مجموعة بروتوكول الإنترنت");
regGS("You do not have the right to delete IP Groups.", "لا يحق لك إلغاء مجموعات بروتوكول الإنترنت");
regGS("No such IP Group.", "ليس هناك مجموعة مماثلة من بروتوكول الإنترنت");
regGS("Deleting IP Group", " الغاء مجموعة بروتوكول الإنترنت");
regGS("The IP Group could not be deleted.", "لا يمكن إلغاء مجموعة بروتوكول الإنترنت");
regGS("No IP Group.", "لا يوجد مجموعة بروتوكول الإنترنت");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/ar/users.php <==
<?php
regGS("65 or over", "");
regGS("User may translate articles", "يحق للمستخدم ترجمة المقالات");
regGS("User may move articles", "يحق للمستخدم نقل المقالات");
regGS("User may find and replace", "يحق للمستخدم البحث والتغير");
regGS("User may change system preferences", "يحق للمستخدم تغير إعدادات النظام");
regGS("User may attach topics to articles", "يحق للمستخدم إضافة المواضيع للمقالات");
regGS("User may attach images to articles", "يحق للمستخدم إضافة الصور للمقالات");
regGS("User may add special characters", "يحق للمستخدم إضافة أحرف خاصة");
regGS("Reset search form", "بحث جديد");
regGS("That user name already exists, please choose a different login name.", "أسم المستخدم موجود. الرجاء إنتقاء أسم دخول أخر.");
regGS("User may delete article attachments", "يحق للمستخدم إلغاء مرفقات المقالة.");
regGS("User may change article attachments", "يحق للمستخدم تعديل مرفقات المقالة.");
regGS("User may add article attachments", "يحق للمستخدم إضافة مرفقات المقالة.");
regGS("Staff management", "إدارة طاقم العمل");
regGS("Subscriber management", "إدارة المشتركين");
regGS("Account Name", "أسم الحساب");
regGS("Full Name", "الإسم الكامل");
regGS("Delete user $1", " $1 إلغاء المستخدم");
regGS("User list is empty.", "قائمة المستخدمين فارغة.");
regGS("You do not have the right to create user accounts.", "لا يحق لك وضع اشتراكات للمستخدم");
regGS("Title", "الوظيفة");
regGS("Gender", "الجنس");
regGS("Mr.", "سيد");
regGS("Mrs.", "سيدة");
regGS("Ms.", "آنسة");
regGS("Dr.", "دكتور");
regGS("Male", "ذكر");
regGS("Female", "أنثى");
regGS("under 18", "دون الـ 18 سنة");
regGS("Age", "العمر");
regGS("Confirm password", "تأكيد كلمة السر");
regGS("E-Mail", "البريد الالكتروني");
regGS("City", "المدينة");
regGS("Street Address", "عنوان الشارع");
regGS("Postal Code", "الرمز البريدي");
regGS("State", "الولاية");
regGS("Phone", "الهاتف");
regGS("Fax", "الفاكس");
regGS("Contact Person", "الشخص المرجع");
regGS("Second Phone", "رقم هاتف ثان");
regGS("Employer", "رب العمل");
regGS("Employer Type", "نوع رب العمل");
regGS("Corporate", "شركة");
regGS("Non-Governmental Organisation", "منظمة غير حكومية");
regGS("Government Agency", "وكالة حكومية");
regGS("Academic", "أكاديمي");
regGS("Media", "إعلام");
regGS("Position", "مركز الوظيفة");
regGS("Show more user details", "إظهار المزيد من تفاصيل المستخدم");
regGS("Hide user details", "إخفاء تفاصيل المستخدم");
regGS("You must select a $1", "  $1عليك الاختيار ");
regGS("The password must be at least 6 characters long and both passwords should match.", "يجب أن تتألف كلمة السر من 6 أحرف على الأقل. كما يجب أن تكون كلمتا السر متشابهتين");
regGS("The user account could not be created.", "لا يمكن وضع اشتراك للمستخدم");
regGS("User account $1 was created successfully.", "تم إنشاء حساب المستخدم $1 بنجاح.");
regGS("Click here to change password", "إضغط هنا لتعديل كلمة السر");
regGS("Old Password", "كلمة السر القديمة");
regGS("You do not have the right to change user account permissions.", "لا يحق لك تغيير الاذن لاشتراك المستخدم");
regGS("Permissions for $1 changed", " $1 تغيير السماح ل ");
regGS("You do not have the right to change user account information.", "لا يحق لك تغيير معلومات اشتراك المستخدم");
regGS("Click here to customize user permissions", "إضغط هنا لتعديل حقوق المستخدم");
regGS("Click here to use existing user type permissions (discard customization)", "إضغط هنا لإستخدام حقوق نوع المستخدم (إهمال التعديلات)");
regGS("Click here to leave password unchanged", "إضغط هنا لإبقاء كلمة السر غير معدلة");
regGS("User account information changed for $1", "معلومات اشتراك المستخدم ل  $1");
regGS("The password you typed is incorrect.", "كلمة السر التي طبعتها غير صحيحة");
regGS("You do not have the right to delete user accounts.", "لا يحق لك إلغاء اشتراكات المستخدم");
regGS("Are you sure you want to delete the user account $1 ?", " هل أنت متأكد من أنك تريد إلغاء اشتراك المستخدم  $1 ؟");
regGS("User account $1 was deleted successfully.", "تم إلغاء حساب المستخدم $1 بنجاح.");
regGS("User IP access list management", "إدارة قائمة دخول المستخدم إلى بروتوكول الإنترنت");
regGS("No records.", "لا بيانات");
regGS("Start IP", "ابدأ بروتوكول الإنترنت");
regGS("Number of addresses", "عدد العناوين");
regGS("The IP Group $1 has been created.", "وضع مجموعة بروتوكول الإنترنت  $1");
regGS("There was an error creating the IP address group.", "حصل خطاء أثناء إنشاء مجموعة الآي بي.");
regGS("Are you sure you want to delete the IP Group $1?", " هل أنت متأكد من أنك تريد إلغاء مجموعة بروتوكول الإنترنت  $1؟");
regGS("The IP address group $1 has been deleted.", "تم الغاء مجموعة عنوان بروتوكول الإنترنت  $1");
regGS("User '$1' information was changed successfully.", "تم تعديل معلومات المستخدم \"$1\" بنجاح");
regGS("IP address", "عنوان الآي بي");
regGS("fill in from left to right at least one input box", "قم بتعبئة خيار واحد على الأقل من اليسار إلى اليمين");
regGS("User Type", "نوع المستخدم");
regGS("You must input a valid EMail address.", "عليك إدخال عنوان بريد إلكتروني صالح.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "يجب أن يتطابقان كلمتي السر وأن لا يقلوا عن ستة أحرف.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "عليك إدخال رقم بين 0 و 255 في الحقل $1 لبداية الآي بي");
regGS("Delete subscriptions to $1", "إلغاء الإشتراك لـ$1");
regGS("Change user account information", "غيّر معلومات اشتراك المستخدم");
regGS("The IP address group $1:$2 conflicts with another existing group.", "مجموعة الآي بي $1:$2 تتعارض مع مجموعة موجودة حالياً.");
regGS("Creation Date", "تاريخ الإنشاء");
regGS("User management", "إدارة المستخدم");
regGS("Set", "مجموعة");
regGS("Update", "تحديث");
regGS("Rights", "حقوق");
regGS("IP Access", "الدخول إلى بروتوكول الإنترنت");
regGS("User Name", "إسم المستخدم");
regGS("Staff", "موظف");
regGS("Adding new user account", "إضافة اشتراك لمستخدم جديد");
regGS("You must select an user type.", "يجب إختيار نوع المستخدم");
regGS("The user account $1 has been created.", "  $1 تم وضع اشتراك للمستخدم");
regGS("Please check if an account with the same user name does not already exist.", "الرجاء التأكد من أن اشتراكاّ باسم هذا المستخدم غير موجود مسبقاً");
regGS("Change password", "تغيير كلمة سرّ المستخدم");
regGS("You do not have the right to change user passwords.", "لا يحق تغيير كلمة سرّ المستخدم");
regGS("Changing user password", "تغيير كلمة سرّ المستخدم");
regGS("The password could not be changed.", "لا يمكن تغيير كلمة السرّ");
regGS("The password has been changed.", "تم تغيير كلمة السر");
regGS("User may manage templates", "يمكن للمستخدم إدارة النماذج");
regGS("User may add/change country entries", "يمكن للمستخدم إضافة بيانات البلدان أم تغييرها");
regGS("Edit user account permissions", "السماح لاشتراك المستخدم");
regGS("This user account does not have permissions information.", "ليس لدى اشتراك المستخدم المعلومات الاذن ");
regGS("Updating user account permissions", "تحديث الاذن لاشتراك المستخدم");
regGS("User account permissions have been successfuly updated.", "لقد تم تحديث الاذن لاشتراك المستخدم ");
regGS("User account permissions could not be updated.", "لا يمكن تغيير الاذن لاشتراك المستخدم");
regGS("Changing user account information", "تغيير معلومات اشتراك المستخدم");
regGS("User account information has been changed.", "تم تغيير معلومات اشتراك المستخدم");
regGS("User account information could not be changed.", "لا يمكن تغيير معلومات اشتراك المستخدم");
regGS("Old password", "كلمة السر القديمة");
regGS("New password", "كلمة السر الجديدة");
regGS("Confirm new password", "تأكيد كلمة السر الجديدة");
regGS("Changing your password", "تغيير كلمة السر الخاصة بك");
regGS("User $1 changed his password", "بدّل المستخدم 1$ كلمة السر الخاصة به");
regGS("Delete user account", "الغاء اشتراك المستخدم");
regGS("Deleting user account", "الغاء اشتراك المستخدم");
regGS("The user account $1 could not be deleted.", "لا يمكن إلغاء اشتراك المستخدم  $1");
regGS("No such user.", "هذا المستخدم غير موجود");
regGS("Delete IP Group $1", "الغاء مجموعة بروتوكول الإنترنت  $1");
regGS("IP Access List", "قائمة الدخول إلى بروتوكول الإنترنت");
regGS("Adding new IP Group", "إضافة مجموعة جديدة من بروتوكول الإنترنت");
regGS("The IP Group could not be created.", "لا يمكن وضع مجموعة بروتوكول الإنترنت ");
regGS("Please check if an account with the same IP Group does not already exist.", " الرجاء التأكد من عدم وجود اشتراك يتضمن مجموعة بروتوكول الإنترنت نفسها");
regGS("Delete IP Group", " إلغ مجموعة بروتوكول الإنترنت");
regGS("You do not have the right to delete IP Groups.", "لا يحق لك إلغاء مجموعات بروتوكول الإنترنت");
regGS("No such IP Group.", "ليس هناك مجموعة مماثلة من بروتوكول الإنترنت");
regGS("Deleting IP Group", " الغاء مجموعة بروتوكول الإنترنت");
regGS("The IP Group could not be deleted.", "لا يمكن إلغاء مجموعة بروتوكول الإنترنت");
regGS("No IP Group.", "لا يوجد مجموعة بروتوكول الإنترنت");
?>
